<?php

namespace Drupal\symfony_messenger_example\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\symfony_messenger_example\Command\ExampleRequest;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Messenger\MessageBus;

/**
 * A controller that dispatches a message to the bus.
 */
class ExampleController extends ControllerBase {

  /**
   * ExampleController constructor.
   *
   * @param \Symfony\Component\Messenger\MessageBus $bus
   *   The message bus.
   */
  final public function __construct(
    private readonly MessageBus $bus,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): ExampleController {
    return new static($container->get('symfony_messenger.bus.default'));
  }

  /**
   * Builds the response.
   *
   * @return array
   *   A render array.
   */
  public function build(): array {
    $this->bus->dispatch(new ExampleRequest('Example title'));

    $build['content'] = [
      '#type' => 'item',
      '#markup' => $this->t('Request dispatched to the bus!'),
    ];

    return $build;
  }

}
